@@ -49,7 +49,7 @@ class TaskContainer(object):
 
             if topic_partitions:
                 if not all(x == topic_partitions.values()[0] for x in topic_partitions.values()):
-                    raise RuntimeError("All source topics must have same number of partitions.")
+                    raise RuntimeError("Failed to initialize task {0}. All source topics must have same number of partitions ({1!r}).".format(task.name, topic_partitions.values()))
 
                 partitions = topic_partitions.values()[0]
 
