@@ -1,4 +1,5 @@
 class SourceMessage(dict):
-    def __init__(self, source, data):
+    def __init__(self, data, source=None, key=None):
         self.source = source
+        self.key = key
         dict.__init__(self, data)
\ No newline at end of file
