@@ -108,6 +108,9 @@ class TaskState(collections.MutableMapping):
         self._changes = set()
 
     def __getitem__(self, key):
+        if key in self._deletes:
+            raise KeyError(key)
+
         if key in self._cache:
             return self._cache[key]
         else:
@@ -141,6 +144,30 @@ class TaskState(collections.MutableMapping):
         else:
             return self._mgr.iterate_keys(*args, **kwargs)
 
+    # def _iterate_key_values(self, *args, **kwargs):
+    #     # merge data from manager with data from _cache
+    #     sorted_changes = sorted(self._changes)
+    #     sorted_deletes = sorted(self._deletes)
+
+    #     for key, val in self._mgr.iterate_key_values(*args, *kwargs):
+    #         # yield all values from changed where x < key and x >= key_from
+
+    #         # if key in deleted, continue
+    #         if key in self._deletes:
+    #             continue
+
+    #         if key in self._changes:
+    #             yield key, self._cache[key]
+
+    #         key_from = key
+
+    #     # for key in changes[new_key_from:key_to]
+    #     # yield key, self._cache[key]
+
+
+    # def _iterate_keys(self, *args, **kwargs):
+    #     pass
+
     # improved methods
     def iteritems(self):
         return self.range()
@@ -170,6 +197,7 @@ class TaskState(collections.MutableMapping):
         self._mgr.commit_state()
         self._changes = set()
         self._deletes = set()
+        self._cache = {}
 
     def clear(self):
         for key in self.iterkeys():
